
import csv
import os
import json


def save_to_json(issue, output_file_path, project_key):
    try:
        os.makedirs(os.path.dirname(output_file_path), exist_ok=True)
        with open(output_file_path, "w", encoding="utf-8") as file:
            file.write(json.dumps(issue.raw, ensure_ascii=False))  
    except Exception as e:
        raise RuntimeError(f"Error while saving to JSON: {e}")


def save_to_jsonl(issues, output_path, project_key):
    jsonl_file_path = os.path.join(output_path, f"{project_key.lower()}.jsonl")
    try:
        os.makedirs(os.path.dirname(jsonl_file_path), exist_ok=True)
        with open(jsonl_file_path, "w", encoding="utf-8") as file:
            for issue in issues:
                file.write(json.dumps(issue.raw, ensure_ascii=False) + "\n")
    except Exception as e:
        raise RuntimeError(f"Error while saving to JSONL: {e}")


def save_to_csv(issues, output_path, project_key):
    csv_file_path = os.path.join(output_path, f"{project_key.lower()}.csv")
    try:
        os.makedirs(os.path.dirname(csv_file_path), exist_ok=True)
        with open(csv_file_path, "w", encoding="utf-8", newline="") as file:
            writer = csv.writer(file)  
            writer.writerow(["ID", "Key", "Summary","StatusDescription","StatusName","AcceptanceCriteria","E2E"])
            for issue in issues:
                writer.writerow([
                    issue.id,
                    issue.key,
                    issue.fields.summary,
                    issue.fields.description,
                    issue.fields.status.name,
                    issue.fields.customfield_10208,
                    issue.fields.customfield_10204.value,
                ])
    except Exception as e:
        raise RuntimeError(f"Error while saving to CSV: {e}")


def save_to_file(issues, output_format, project_key, output_path):
    if output_format == 'jsonl':
        save_to_jsonl(issues, output_path, project_key)
    elif output_format == "csv":
        save_to_csv(issues, output_path, project_key)


def save_to_multiple_files(issues, output_dir, file_name_prefix):
    file_paths = []
    for issue in issues:
        json_file_path = os.path.join(output_dir, f"{file_name_prefix.lower()}-{issue.key}.json")
        save_to_json(issue, json_file_path, file_name_prefix)
        file_paths.append(json_file_path)
    
    return file_paths